package org.rcisoft.tencent.controller;

import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.jwt.util.CyJwtUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.tencent.service.CyWxMiniService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * @author cy
 * Created by cy on 21/5/10.
 * @descript
 */
@RestController
@RequestMapping("/wxMiniApp")
@Slf4j
public class CyWxMiniAppController {

    @Autowired
    private CyWxMiniService cyWxMiniServiceImpl;

    @Autowired
    private CyJwtUtil cyJwtUtil;


    /**
     * 获取当前用户个人信息
     * @param request
     * @return
     */
    @GetMapping("/getUserInfo")
    public CyResult getUserInfo(HttpServletRequest request){
        //获取当前用户手机号
        Integer userId = Integer.valueOf(CyUserUtil.getUserInfoStrProp(cyJwtUtil.getToken(request), CyUserUtil.USER_ID));
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cyWxMiniServiceImpl.getUserInfo(userId));
    }

    /**
     * wx login  第一步
     * 1. 小程序刚进入的时候，可能会有token
     * 2. 手机号登录，之前调用的
     * 3. 判断登录的用户是否和数据库匹配,如果不匹配提示错误信息
     *
     * @param code     code
     * @param userType userType 用户类型 0-内部员工 1-外部访客
     * @return
     */
    @GetMapping("/validLogin")
    public Map<String, Object> validLogin(@RequestParam("code") String code, @RequestParam("userType") String userType, HttpServletRequest request) {
        // 1. 已经登录 ----> 延长登录过期时间 30分钟，返回token 和 基本信息(身份)
        return cyWxMiniServiceImpl.validLogin(code, userType, cyJwtUtil.getToken(request));
    }

    /**
     * 手机号登录  第二步
     *
     * @return
     */
    @GetMapping("/phoneLogin")
    public Map<String, Object> phoneLogin(@RequestParam("userType") String userType,
                                          @RequestParam("encryptedData") String encryptedData,
                                          @RequestParam("iv") String iv,
                                          @RequestParam("openId") String openId) {
        return cyWxMiniServiceImpl.phoneLogin(userType,encryptedData, iv, openId);
    }


    /**
     * 保存授权信息 第三步
     *
     * @return
     */
    @PostMapping("/saveUserProfile")
    public Map<String, Object> saveUserProfile(HttpServletRequest request,
                                               @RequestParam("nickName") String nickName,
                                               @RequestParam("avatarUrl") String avatarUrl,
                                               @RequestParam("gender") String gender,
                                               @RequestParam("address") String address) {
        return cyWxMiniServiceImpl.saveUserProfile(nickName, avatarUrl, gender, address, cyJwtUtil.getToken(request));
    }


}
